Label

Function Label 

pub fn Label(props: LabelProps) -> Element
Renders an unstyled label associated with the resolved metadata’s control id.

This part can resolve metadata from Field Context, accept it explicitly, or run standalone.