pub struct BindingPropTrio<T: 'static> {
pub value: ReadSignal<T>,
pub on_change: Callback<T>,
pub on_commit: Callback<()>,
}Expand description
A carrier for the lower-level prop contract implemented by field-shaped widgets.
Decompose this carrier into three separate props to keep a widget independent from this crate.
Since on_change does not carry a ChangeOrigin, calling it represents a user change.
Fields
value: ReadSignal<T>The reactive value read by the widget.
on_change: Callback<T>The callback invoked when user interaction changes the value.
on_commit: Callback<()>The callback invoked at the widget-defined end of an interaction unit.