pub struct BindingTypeMismatch { /* private fields */ }Expand description
A requested binding type did not match the binding stored in a FieldContext.
Implementations
Sourceimpl BindingTypeMismatch
impl BindingTypeMismatch
Sourcepub const fn actual_type_name(&self) -> &'static str
pub const fn actual_type_name(&self) -> &'static str
Returns the value type of the binding stored in the context.
Sourcepub const fn requested_type_name(&self) -> &'static str
pub const fn requested_type_name(&self) -> &'static str
Returns the value type requested by the control.