pub struct LabelProps {
pub meta: Option<FieldMeta>,
pub invalid: Option<bool>,
pub disabled: Option<bool>,
pub attributes: Vec<Attribute>,
pub children: Element,
}Expand description
Props for the headless Label part.
Fields
meta: Option<FieldMeta>Explicit metadata, which wins over Field Context metadata.
invalid: Option<bool>Explicit invalid state, which wins over the metadata state.
disabled: Option<bool>Explicit disabled state, which wins over the metadata state.
attributes: Vec<Attribute>Attributes forwarded to the rendered label.
children: ElementLabel content.
Implementations
Sourceimpl LabelProps
impl LabelProps
Sourcepub fn builder() -> LabelPropsBuilder<((), (), (), (), ())>
pub fn builder() -> LabelPropsBuilder<((), (), (), (), ())>
Create a builder for building LabelProps.
On the builder, call .meta(...)(optional), .invalid(...)(optional), .disabled(...)(optional), .attributes(...)(optional), .children(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of LabelProps.