pub fn assert_binding_resolution_precedence<T: Debug + PartialEq + 'static>(
resolved_with_explicit: &Binding<T>,
explicit: &Binding<T>,
resolved_with_context: &Binding<T>,
context: &Binding<T>,
internal_value: T,
expected_internal_value: T,
)Expand description
Asserts explicit binding, context binding, then internal-state resolution precedence.
The registry adapter should expose the binding its widget resolved in the first two scenarios and the value observed after writing its uncontrolled binding in the final scenario.
Panics
Panics when either resolved binding has the wrong identity or internal state did not retain its write.