pub struct ChangeOriginProbe<T> { /* private fields */ }Expand description
Records values written through a Binding together with their ChangeOrigin.
Implementations
Sourceimpl<T> ChangeOriginProbe<T>
impl<T> ChangeOriginProbe<T>
Sourceimpl<T: 'static> ChangeOriginProbe<T>
impl<T: 'static> ChangeOriginProbe<T>
Sourcepub fn binding(&self, read: ReadSignal<T>) -> Binding<T>
pub fn binding(&self, read: ReadSignal<T>) -> Binding<T>
Creates a binding whose writes are recorded by this probe.
Sourcepub fn binding_with_commit(
&self,
read: ReadSignal<T>,
on_commit: Callback<()>,
) -> Binding<T>
pub fn binding_with_commit( &self, read: ReadSignal<T>, on_commit: Callback<()>, ) -> Binding<T>
Creates a binding whose writes are recorded and whose commits use on_commit.
Sourceimpl<T: Debug + PartialEq> ChangeOriginProbe<T>
impl<T: Debug + PartialEq> ChangeOriginProbe<T>
Sourcepub fn assert_writes(&self, expected: &[(T, ChangeOrigin)])
pub fn assert_writes(&self, expected: &[(T, ChangeOrigin)])
Asserts the complete ordered sequence of value and origin pairs.
Panics
Panics when the observed writes differ from expected.