pub fn Label(props: LabelProps) -> ElementExpand description
Renders an unstyled label associated with the resolved metadata’s control id.
This part can resolve metadata from Field Context, accept it explicitly, or run standalone.
pub fn Label(props: LabelProps) -> ElementRenders an unstyled label associated with the resolved metadata’s control id.
This part can resolve metadata from Field Context, accept it explicitly, or run standalone.