use_binding

Function use_binding 

pub fn use_binding<T: 'static>(
    explicit: Option<Binding<T>>,
    default: T,
) -> Binding<T>
Resolves a binding using explicit prop, FieldContext, then uncontrolled-state precedence.

The internal signal hook is called regardless of which source wins so the resolution order can change between renders without violating Dioxus’s hook ordering rules.

Panics

Panics when there is no explicit binding and the Field Context contains a binding for a value type other than T.