FieldDescriptionProps

Struct FieldDescriptionProps 

pub struct FieldDescriptionProps {
    pub id: Rc<str>,
    pub meta: Option<FieldMeta>,
    pub invalid: Option<bool>,
    pub disabled: Option<bool>,
    pub attributes: Vec<Attribute>,
    pub children: Element,
}
Props for the headless FieldDescription part.

Fields

id: Rc<str>

Stable id registered with the resolved field metadata for this part’s lifetime.

meta: Option<FieldMeta>

Explicit metadata, which wins over Field Context metadata.

invalid: Option<bool>

Explicit invalid state, which wins over the metadata state.

disabled: Option<bool>

Explicit disabled state, which wins over the metadata state.

attributes: Vec<Attribute>

Attributes forwarded to the rendered description div.

children: Element

Description content.

Implementations

Source

impl FieldDescriptionProps

pub fn builder() -> FieldDescriptionPropsBuilder<((), (), (), (), (), ())>

Create a builder for building FieldDescriptionProps. On the builder, call .id(...), .meta(...)(optional), .invalid(...)(optional), .disabled(...)(optional), .attributes(...)(optional), .children(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of FieldDescriptionProps.